@@ -1,9 +1,9 @@
 # coding:utf-8
-from tools_hjh import other as tools
 import os
 import time
 from tools_hjh.ThreadPool import ThreadPool
 from tools_hjh.HTTPRequest import HTTPRequest
+from tools_hjh.Tools import rm, mkdir
 
     
 def main():
@@ -21,7 +21,7 @@ class HTTPTools():
         text = req.get_text()
         req.close()
         return text
-
+    
     @staticmethod
     def download(url, dstfile, headers=None, data=None, proxies=None, maxRetryCount=5, nowRetryCount=0, minSize=1024):
         """ 重新指定url等参数，执行下载 """
@@ -43,7 +43,7 @@ class HTTPTools():
                 time.sleep(0.2)
                 size = HTTPTools.download(url, dstfile, headers, data, proxies, maxRetryCount=maxRetryCount, nowRetryCount=nowRetryCount, minSize=minSize)
             elif size < minSize and maxRetryCount <= nowRetryCount:
-                tools.rm(dstfile)
+                rm(dstfile)
                 size = 0
         return size
     
@@ -61,7 +61,7 @@ class HTTPTools():
             m3u8TmpFileDir = dstfile.split('.')[0]
         elif '/' not in dstfile and '.' not in dstfile:
             m3u8TmpFileDir = dstfile
-        tools.mkdir(m3u8TmpFileDir)
+        mkdir(m3u8TmpFileDir)
         # 取得url的开头网址和url的不包含文件名的url
         urlSplits = url.split('/')
         urlHead = urlSplits[0] + '//' + urlSplits[2]
@@ -119,7 +119,7 @@ class HTTPTools():
                     tsfileRead = HTTPTools.aes_decrypt(tsfileRead, key, mode)
                 size = size + dstfile.write(tsfileRead)
                 tsfile.close()
-        tools.rm(m3u8TmpFileDir)
+        rm(m3u8TmpFileDir)
         dstfile.close()
         return size
 
@@ -221,14 +221,28 @@ class HTTPTools():
         return aes.decrypt(b)
     
     @staticmethod
-    def N_m3u8DL_CLI(url, workDir, dstfile, theadnum=32, exePath='N_m3u8DL-CLI'):
-        if workDir is None:
-            workDir = os.path.abspath(os.path.dirname(__file__)) + '/' + dstfile.rsplit('/', 1)[0]
+    def N_m3u8DL_CLI(url, work_dir, dstfile, theadnum=32, exe_path='N_m3u8DL-CLI'):
+        if work_dir is None:
+            work_dir = os.path.abspath(os.path.dirname(__file__)) + '/' + dstfile.rsplit('/', 1)[0]
         dstfile = dstfile.split('/')[-1]
-        cmd = exePath + ' --workDir ' + workDir + ' --saveName ' + dstfile + ' --maxThreads ' + str(theadnum) + ' --enableDelAfterDone ' + url
-        print(cmd)
+        cmd = exe_path + ' --workDir ' + work_dir + ' --saveName ' + dstfile + ' --maxThreads ' + str(theadnum) + ' --enableDelAfterDone ' + url
+        os.popen('chcp 65001')
+        os.system(cmd)
+        
+    @staticmethod
+    def BitComet(url, dstfile, exe_path):
+        cmd = 'start /b ' + exe_path + ' --url ' + url + ' -o ' + dstfile + ' -s –-tray'
+        os.popen('chcp 65001')
         os.system(cmd)
 
 
+class BitComet():
+
+    def __init__(self, exe_path):
+        cmd = exe_path + ' –-tray'
+        os.popen('chcp 65001')
+        os.system(cmd)
+
+    
 if __name__ == '__main__':
     main()
