@@ -1,8 +1,10 @@
 # coding:utf-8
-from tools_hjh import other as tools
+from tools_hjh.Log import Log
 from tools_hjh.DBConn import DBConn
 from tools_hjh.DBConn import QueryResults
 from tools_hjh.MemoryDB import MemoryDB
+from tools_hjh.Tools import line_merge_align, locatdate, merge_spaces, \
+    analysis_hosts, locattime
 
 
 def main():
@@ -206,7 +208,7 @@ class OracleTools:
             dst_desc = OracleTools.desc(dst_dba_conn, dst_username, tab[0])
             if src_desc != dst_desc:
                 table_list.append(tab[0])
-                out = out + tools.line_merge_align(src_username + '.' + tab[0] + '\n' + src_desc
+                out = out + line_merge_align(src_username + '.' + tab[0] + '\n' + src_desc
                                            , dst_username + '.' + tab[0] + '\n' + dst_desc
                                            , True) + '\n\n'
         return table_list, out
@@ -346,7 +348,7 @@ class OracleTools:
     @staticmethod   
     def expdp_estimate(host_conn, sid, users='', estimate='statistics'):
         """ 评估导出的dmp文件大小, users不填会使用full=y, estimate=statistics|blocks """
-        date_str = tools.locatdate()
+        date_str = locatdate()
         ip = host_conn.host
         if users == '':
             sh = '''
@@ -382,7 +384,7 @@ class OracleTools:
                 if 'Total' in line or 'expdp' in line:
                     pass
                 else:
-                    line = tools.merge_spaces(line.replace('"', '')).strip()
+                    line = merge_spaces(line.replace('"', '')).strip()
                     user_name = line.split(' ')[0].split('.')[0]
                     obj_name = line.split(' ')[0].split('.')[1]
                     obj_size = line.split(' ')[1]
@@ -404,7 +406,7 @@ class OracleTools:
             
             for line in lines:
                 if '.   "' in line:
-                    line = tools.merge_spaces(line.replace('"', '').replace('\n', '')).strip()
+                    line = merge_spaces(line.replace('"', '').replace('\n', '')).strip()
                     user_name = line.split(' ')[1].split('.')[0]
                     obj_name = line.split(' ')[1].split('.')[1]
                     obj_size = line.split(' ')[2]
@@ -428,9 +430,9 @@ class OracleTools:
     def expdp(src_host_conn, src_dba_conn, src_ora_sid, src_ora_user='', dump_tmp_py='/tmp/oracle_dump_py'):
         if src_ora_user == '':
             src_ora_user = 'all'
-        date_str = tools.locatdate()
+        date_str = locatdate()
         dump_filename = src_ora_user + '_' + date_str + '.dmp'
-        log = tools.Log('logs/expdp.log')
+        log = Log('logs/expdp.log')
         src_ora_user = ''
         
         # 源端创建DUMP_TMP_PY
@@ -486,10 +488,10 @@ class OracleTools:
         """
         if src_ora_user == '':
             src_ora_user = 'all'
-        date_str = tools.locatdate()
+        date_str = locatdate()
         dump_filename = src_ora_user + '_' + date_str + '.dmp'
         dump_logname = src_ora_user + '_' + date_str + '.log'
-        log = tools.Log('logs/expdp_scp_impdp.log')
+        log = Log('logs/expdp_scp_impdp.log')
         src_ora_user = ''
         
         # 源端创建DUMP_TMP_PY
@@ -596,7 +598,7 @@ class OracleTools:
     def analysis_tns(host_conn):
         """ 解析Oracle tnsnames.ora文件 """
         """ tns_name, ip, port, sid, service_name """
-        host_map = tools.analysis_hosts(host_conn)
+        host_map = analysis_hosts(host_conn)
         cmd = '''source ~/.bash_profile;cat $ORACLE_HOME/network/admin/tnsnames.ora'''
         tns_str = host_conn.exec_command(cmd)
         tns_str2 = ''
@@ -606,7 +608,7 @@ class OracleTools:
             if not line.startswith('#'):
                 tns_str2 = tns_str2 + line + '\n'
         tns_str2 = tns_str2.replace('\n', ' ')
-        tns_str2 = tools.merge_spaces(tns_str2)
+        tns_str2 = merge_spaces(tns_str2)
         for s in tns_str2.split(') ) )'):
             s = s.replace(' ', '')
             if len(s) > 0:
@@ -634,7 +636,7 @@ class OracleTools:
     @staticmethod     
     def analysis_ogg_status(host_conn):
         """ 进入主机全部找到的ggsci，执行info all 返回结果 """
-        query_time = tools.locattime()
+        query_time = locattime()
         host = host_conn.host
         
         # 进程状态 
@@ -650,10 +652,10 @@ class OracleTools:
             mess = host_conn.exec_command(cmd)
             for line in mess.split('\n'):
                 if line.startswith('MANAGER'):
-                    lines = tools.merge_spaces(line).split(' ')
+                    lines = merge_spaces(line).split(' ')
                     ogg_status.get_rows().append((query_time, host, path, lines[0].lower(), lines[1].lower()))
                 elif line.startswith('EXTRACT') or line.startswith('REPLICAT'):
-                    lines = tools.merge_spaces(line).split(' ')
+                    lines = merge_spaces(line).split(' ')
                     ogg_status.get_rows().append((query_time, host, path, lines[0].lower(), lines[1].lower(), lines[2].lower(), lines[3], lines[4]))
         
         return ogg_status
@@ -687,7 +689,7 @@ class OracleTools:
                 ogg_type = ''
                 
                 for line in param.split('\n'):
-                    line_ = tools.merge_spaces(line).strip().lower().replace(', ', ',').replace('; ', ';')
+                    line_ = merge_spaces(line).strip().lower().replace(', ', ',').replace('; ', ';')
                     if line_.startswith('extract '):
                         ogg_type = 'ext_or_dmp'
                     elif line_.startswith('replicat '):
@@ -711,7 +713,7 @@ class OracleTools:
                     ext_info['ggsci_path'] = ggsci_path
                     ext_info['ogg_type'] = ogg_type
                     for line in param.split('\n'):
-                        line_ = tools.merge_spaces(line).strip().lower().replace(', ', ',').replace('; ', ';')
+                        line_ = merge_spaces(line).strip().lower().replace(', ', ',').replace('; ', ';')
                         if line_.startswith('extract '):
                             ext_info['ogg_name'] = line_.split(' ')[1]
                         elif line_.startswith('userid '):
@@ -752,7 +754,7 @@ class OracleTools:
                     dmp_info['ggsci_path'] = ggsci_path
                     dmp_info['ogg_type'] = ogg_type
                     for line in param.split('\n'):
-                        line_ = tools.merge_spaces(line).strip().lower().replace(', ', ',').replace('; ', ';')
+                        line_ = merge_spaces(line).strip().lower().replace(', ', ',').replace('; ', ';')
                         if line_.startswith('extract '):
                             dmp_info['ogg_name'] = line_.split(' ')[1]
                         elif line_.startswith('userid '):
@@ -809,7 +811,7 @@ class OracleTools:
                     rep_info['ggsci_path'] = ggsci_path
                     rep_info['ogg_type'] = ogg_type
                     for line in param.split('\n'):
-                        line_ = tools.merge_spaces(line).strip().lower().replace(', ', ',').replace('; ', ';')
+                        line_ = merge_spaces(line).strip().lower().replace(', ', ',').replace('; ', ';')
                         if line_.startswith('replicat '):
                             rep_info['ogg_name'] = line_.split(' ')[1]
                         elif line_.startswith('userid '):
@@ -832,7 +834,7 @@ class OracleTools:
                                 rep_info['ora_sid'] = default_sid
                         elif line_.startswith('map ') and 'target ' in line_:
                             line_ = line_.replace(',', ' ')
-                            line_ = tools.merge_spaces(line_)
+                            line_ = merge_spaces(line_)
                             m = line_.split(' ')[1].replace('"', '')
                             t = line_.split(' ')[3].replace(';', '').replace('"', '').strip().lower()
                             rep_info['write_table_maps'].append((m, t))
@@ -857,12 +859,12 @@ class OracleTools:
                     rep2kafka_info['ggsci_path'] = ggsci_path
                     rep2kafka_info['ogg_type'] = ogg_type
                     for line in param.split('\n'):
-                        line_ = tools.merge_spaces(line).strip().lower().replace(', ', ',').replace('; ', ';')
+                        line_ = merge_spaces(line).strip().lower().replace(', ', ',').replace('; ', ';')
                         if line_.startswith('replicat '):
                             rep2kafka_info['ogg_name'] = line_.split(' ')[1]
                         elif line_.startswith('map ') and 'target ' in line_:
                             line_ = line_.replace(',', ' ')
-                            line_ = tools.merge_spaces(line_)
+                            line_ = merge_spaces(line_)
                             m = line_.split(' ')[1].replace('"', '')
                             t = line_.split(' ')[3].replace(';', '').replace('"', '').strip().lower()
                             rep2kafka_info['write_table_maps'].append((m, t))
