@@ -2,7 +2,7 @@
 import paramiko
 import os
 import time
-from tools_hjh.other import remove_leading_space
+from tools_hjh.Tools import remove_leading_space
 
 
 class SSHConn:
