@@ -8,8 +8,9 @@ from tools_hjh.SSHConn import SSHConn
 from tools_hjh.ThreadPool import ThreadPool
 
 from tools_hjh.HTTPRequest import HTTPRequest
+from tools_hjh.Chrome import Chrome
 from tools_hjh.HTTPTools import HTTPTools
 
-from tools_hjh.other import Log
+from tools_hjh.Log import Log
 
-import tools_hjh.other as Tools
+import tools_hjh.Tools as Tools
